party_crosswalk: GERDA

View source: R/party_crosswalk.R

party_crosswalkR Documentation

GERDA

Description

This function creates a crosswalk between parties and their corresponding names using the ParlGov view_party table. In cases where the party name is not found in the view_party table, the function returns NA. Note that this function should be run on GERDA party names, and will likely not work on other party naming schemes.

Usage

party_crosswalk(party_gerda, destination)

Arguments

party_gerda

A character vector containing the GERDA party names to be converted.

destination

The name of the column in the view_party table to map to.

Value

A vector with the mapped party names.

Examples

party_crosswalk(c("cdu", "spd", "linke_pds", NA), "left_right")


gerda documentation built on Nov. 13, 2025, 1:07 a.m.