load_gerda_web: Load GERDA Data

View source: R/load_gerda_web.R

load_gerda_webR Documentation

Load GERDA Data

Description

This function loads GERDA data from a web source.

Usage

load_gerda_web(file_name, verbose = FALSE, file_format = "rds")

Arguments

file_name

A character string specifying the name of the file to load. For a list of available data, see gerda_data_list.

verbose

A logical value indicating whether to print additional messages to the console. Default is FALSE.

file_format

A character string specifying the format of the file. Must be either "csv" or "rds". Default is "rds".

Value

A tibble containing the loaded data, or NULL if the data could not be loaded.

Examples


# Load harmonized municipal elections data
data_municipal_harm <- load_gerda_web("municipal_harm", verbose = TRUE, file_format = "rds")

# Load federal election data harmonized to 2025 boundaries (includes 2025 election)
data_federal_2025 <- load_gerda_web("federal_muni_harm_25", verbose = TRUE, file_format = "rds")



gerda documentation built on Nov. 13, 2025, 1:07 a.m.