View source: R/load_gerda_web.R
| load_gerda_web | R Documentation |
This function loads GERDA data from a web source.
load_gerda_web(file_name, verbose = FALSE, file_format = "rds")
file_name |
A character string specifying the name of the file to load. For a list of available data, see |
verbose |
A logical value indicating whether to print additional messages to the console. Default is FALSE. |
file_format |
A character string specifying the format of the file. Must be either "csv" or "rds". Default is "rds". |
A tibble containing the loaded data, or NULL if the data could not be loaded.
# Load harmonized municipal elections data
data_municipal_harm <- load_gerda_web("municipal_harm", verbose = TRUE, file_format = "rds")
# Load federal election data harmonized to 2025 boundaries (includes 2025 election)
data_federal_2025 <- load_gerda_web("federal_muni_harm_25", verbose = TRUE, file_format = "rds")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.