View source: R/party_crosswalk.R
| party_crosswalk | R Documentation |
This function creates a crosswalk between parties and their corresponding names using the ParlGov view_party table. In cases where the party name is not found in the view_party table, the function returns NA. Note that this function should be run on GERDA party names, and will likely not work on other party naming schemes.
party_crosswalk(party_gerda, destination)
party_gerda |
A character vector containing the GERDA party names to be converted. |
destination |
The name of the column in the view_party table to map to. |
A vector with the mapped party names.
party_crosswalk(c("cdu", "spd", "linke_pds", NA), "left_right")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.