party_crosswalk: Map GERDA Party Names to ParlGov Attributes
Description
This function creates a crosswalk between parties and their corresponding names using the ParlGov view_party table. In cases where the party name is not found in the view_party table, the function returns NA. Note that this function should be run on GERDA party names, and will likely not work on other party naming schemes.
Usage
party_crosswalk(party_gerda, destination)
Value
A vector with the mapped party names.
Arguments
party_gerda
A character vector containing the GERDA party names to be converted.
destination
The name of the column in the view_party table to map to.